<?php

namespace Drupal\ino_header\Plugin\Block;

use Drupal\file\Entity\File;
use Drupal\ino_complementary_content\InoCustomBlock;
use Drupal\site_settings\Entity\SiteSettingEntity;

/**
 * Class InoHeader.
 *
 * @Block(
 *   id = "header_block",
 *   admin_label= @Translation("Custom header"),
 *   category = @Translation("Custom blocks")
 * )
 *
 * @package Drupal\ino_header\Plugin\Block
 */
class InoHeader extends InoCustomBlock {

  /**
   * {@inheritdoc}
   */
  protected $siteSettingsType = 'ino_ss_header';

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   *   Thrown if the entity type doesn't exist.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   *   Thrown if the storage handler couldn't be loaded.
   */
  public function build() {
    $build = [];

    /** @var \Drupal\site_settings\Entity\SiteSettingEntity $header_settings */
    $header_settings = $this->loadSiteSettings();
    if (NULL !== $header_settings) {
      $build = [
        '#theme' => 'ino_header',
        '#logo' => $this->getLogo($header_settings),
        '#site_name' => $this->getSiteName($header_settings),
        '#slogan' => $this->getSlogan($header_settings),
        '#cache' => [
          'tags' => $header_settings->getCacheTags(),
        ],
      ];
    }

    return $build;
  }

  /**
   * Loads the logo file from the configuration page.
   *
   * @param null|\Drupal\site_settings\Entity\SiteSettingEntity $settings
   *   The source site_settings entity.
   *
   * @return array
   *   The file render array.
   */
  protected function getLogo($settings) {
    if ($settings instanceof SiteSettingEntity) {
      $logo = $settings->get('field_ss_logo')->entity;
      if ($logo instanceof File) {
        return [
          '#theme' => 'image_style',
          '#style_name' => 'thumbnail',
          '#uri' => $logo->getFileUri(),
        ];
      }
    }
    return NULL;
  }

  /**
   * Loads the site name from the configuration page.
   *
   * @param null|\Drupal\site_settings\Entity\SiteSettingEntity $settings
   *   The source site_settings entity.
   *
   * @return array
   *   The site name render array.
   */
  protected function getSiteName($settings) {
    $title = [
      '#markup' => '',
    ];
    if (!($settings instanceof SiteSettingEntity)) {
      return $title;
    }

    $name_field = $settings->get('field_ss_sitename');
    if (empty($name_field) || empty($name_field->getValue()) || empty($name_field->getValue()[0]['value'])) {
      return $title;
    }

    $title['#markup'] = $name_field->getValue()[0]['value'];

    return $title;
  }

  /**
   * Loads the site slogan from the configuration page.
   *
   * @param null|\Drupal\site_settings\Entity\SiteSettingEntity $settings
   *   The source site_settings entity.
   *
   * @return array
   *   The site slogan render array.
   */
  protected function getSlogan($settings) {
    $slogan = [
      '#markup' => '',
    ];
    if (!($settings instanceof SiteSettingEntity)) {
      return $slogan;
    }

    $slogan_field = $settings->get('field_ss_slogan');
    if (empty($slogan_field) || empty($slogan_field->getValue()) || empty($slogan_field->getValue()[0]['value'])) {
      return $slogan;
    }

    $slogan['#markup'] = $slogan_field->getValue()[0]['value'];

    return $slogan;
  }

}
