<?php

namespace Drupal\ino_pt_social_post\Factory;

use Drupal\Component\Utility\Html;
use Drupal\Core\Entity\TranslatableInterface;
use Drupal\ino_pt_social_post\Plugin\Field\FieldType\socialPost;
use Drupal\ino_pt_social_post\SocialPostFormatter\FacebookPostFormatter;
use Drupal\ino_pt_social_post\SocialPostFormatter\LinkedInPostFormatter;
use Drupal\ino_pt_social_post\SocialPostFormatter\SocialPostFormatterInterface;
use Drupal\ino_pt_social_post\SocialPostFormatter\TwitterPostFormatter;
use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;

/**
 * Class SocialPostFormatterFactory.
 *
 * @package Drupal\ino_pt_social_post\Factory
 */
class SocialPostFormatterFactory implements SocialPostFormatterFactoryInterface {

  /**
   * Factory method to decorate queries with filters.
   *
   * @param \Drupal\ino_pt_social_post\Plugin\Field\FieldType\socialPost $item
   *   The field item.
   * @param string $langcode
   *   The language code.
   *
   * @return \Drupal\ino_pt_social_post\SocialPostFormatter\SocialPostFormatterInterface
   *   A new filter decorator class.
   *
   * @throws \Symfony\Component\DependencyInjection\Exception\InvalidArgumentException
   *   Occurs when the arguments are not coherent or not supported.
   */
  public static function createInstance(socialPost $item, string $langcode): SocialPostFormatterInterface {

      // Set the entity in the correct language for display.
      if ($item instanceof TranslatableInterface) {
        $item = \Drupal::service('entity.repository')->getTranslationFromContext($item, $langcode);
      }

      $social_network = Html::cleanCssIdentifier(
        $item->getValue()['value']
      );

      switch ($social_network) {
        case TwitterPostFormatter::SOCIAL_NETWORK_NAME:
          return new TwitterPostFormatter($item, $langcode);

        case FacebookPostFormatter::SOCIAL_NETWORK_NAME:
          return new FacebookPostFormatter($item, $langcode);

        case LinkedInPostFormatter::SOCIAL_NETWORK_NAME:
          return new LinkedInPostFormatter($item, $langcode);

        default:
          throw new InvalidArgumentException(
            \sprintf('%s social network type has no support', $social_network)
          );
      }

  }

}
