<?php

namespace Drupal\ino_pt_social_post\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\options\Plugin\Field\FieldType\ListItemBase;

/**
 * Provides a social post field type.
 *
 * @FieldType(
 *   id = "social-post",
 *   label = @Translation("Social post"),
 *   default_widget = "social-post",
 *   default_formatter = "social-post"
 * )
 */
class SocialPost extends ListItemBase {

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition): array {
    return [
      'columns' => [
        'title' => [
          'type' => 'varchar',
          'length' => 255,
        ],
        'content' => [
          'type' => 'text',
          'size' => 'big',
        ],
        'value' => [
          'type' => 'varchar',
          'length' => 255,
        ],
        'language' => [
          'type' => 'varchar_ascii',
          'length' => 255,
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function allowedValuesDescription(): string {
    $description = '<p>' . t('The possible values the Networks field can contain. Enter one value per line, in the format key|label.');
    $description .= '<br/>' . t('The key is the stored value. The label will be used in displayed values and edit forms. For example: linkedin|LinkedIn');
    $description .= '<br/>' . t('The label is optional: if a line contains a single string, it will be used as key and label.');
    $description .= '</p>';
    return $description;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value1 = $this->get('title')->getValue();
    $value2 = $this->get('content')->getValue();
    $value3 = $this->get('value')->getValue();
    $value4 = $this->get('language')->getValue();
    return empty($value1) && empty($value2) && empty($value3) && empty($value4);
  }


  /**
   * @inheritDoc
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['title'] = DataDefinition::create('string')
      ->setLabel(t('Admin title'))
      ->setDescription(t('The post admin title'));

    $properties['content'] = DataDefinition::create('string')
      ->setLabel(t('Content'))
      ->setDescription(t('The post content'));

    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Social network'))
      ->setDescription(t('The social network on which the post will be share'));

    $properties['language'] = DataDefinition::create('string')
      ->setLabel(t('Language'))
      ->setDescription(t('The language'));

    return $properties;
  }

}