<?php

namespace Drupal\ino_pt_social_post\SocialPostFormatter;

use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Class FacebookPostFormatter.
 *
 * @package Drupal\ino_pt_social_post\SocialPostFormatter
 */
class LinkedInPostFormatter extends SocialPostFormatterBase {

  /**
   * Social network name.
   */
  public const SOCIAL_NETWORK_NAME = 'linkedin';

  /**
   * Social network uri.
   *
   * @var string
   */
  protected $uri = 'https://www.linkedin.com/shareArticle';

  /**
   * Social network text formatter suffix.
   *
   * @var string
   */
  protected $formatSuffix = '';

  /**
   * {@inheritdoc}
   */
  protected function getContentFormat(string $format): string {
    return $format;
  }

  /**
   * {@inheritdoc}
   */
  protected function getButtonLink(): Link {
    // Get message:
    $content = $this->getContent();
    // Remove all HTML tags in message.
    $button_text = $this->cleanMessage($content, $this->getContentFormat('ino_format_social_post'));

    // Get current site url.
    $current_url = Url::fromRoute('<current>', [], ['absolute' => TRUE])->toString();

    // Add url parameter to message.
    $url_options = [
      'attributes' => [
        'target' => '_blank',
      ],
      'query' => [
        'mini' => 'true',
        'url' => $current_url,
        'summary' => $button_text,
      ],
    ];

    // Generate url:
    $url = Url::fromUri($this->uri, $url_options);

    return Link::fromTextAndUrl($this->t('Post to LinkedIn'), $url);
  }

}
