<?php

namespace Drupal\ino_pt_social_post\SocialPostFormatter;

use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Class TwitterPostFormatter.
 *
 * @package Drupal\ino_pt_social_post\SocialPostFormatter
 */
class TwitterPostFormatter extends SocialPostFormatterBase {

  /**
   * Social network name.
   */
  public const SOCIAL_NETWORK_NAME = 'twitter';

  /**
   * Social network uri.
   *
   * @var string
   */
  protected $uri = 'https://twitter.com/intent/tweet';

  /**
   * Social network text formatter suffix.
   *
   * @var string
   */
  protected $formatSuffix = '_twitter';

  /**
   * {@inheritdoc}
   */
  protected function getContentFormat(string $format): string {
    return $format . $this->formatSuffix;
  }

  /**
   * {@inheritdoc}
   */
  protected function getButtonLink(): Link {
    // Get message:
    $content = $this->getContent();
    // Remove all HTML tags in message.
    $button_text = $this->cleanMessage($content, $this->getContentFormat('ino_format_social_post'));
    // Add url parameter to message.
    $url_options = [
      'attributes' => [
        'target' => '_blank',
      ],
      'query' => [
        'text' => $button_text,
      ],
    ];

    // Generate url:
    $url = Url::fromUri($this->uri, $url_options);

    return Link::fromTextAndUrl($this->t('Tweet'), $url);
  }

}
