<?php

namespace Drupal\ino_pt_timelineitem\Plugin\Validation\Constraint;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates the Empty value constraint.
 */
class InoEmptyTimelineitemValidator extends ConstraintValidator {

  /**
   * Valid if at least one custom field has a value (not empty).
   *
   * {@inheritdoc}
   */
  public function validate($paragraph, Constraint $constraint) {
    if ($paragraph->getType() == 'ino_pt_timelineitem') {
      $empty = TRUE;
      $fields = $paragraph->getFieldDefinitions();
      // Check if custom fields are empty and set error to false if not.
      foreach ($fields as $field) {
        $field_name = $field->getName();
        // Check only custom fields.
        if (strpos($field_name, 'field') === 0 && !$paragraph->get($field_name)->isEmpty()) {
          $empty = FALSE;
        }
      }
      if ($empty) {
        $this->context->addViolation($constraint->empty);
      }
    }
  }

}
